==> activity-center-api-0.13.86-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/staticpage/UpdatePageVerifyResultDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.staticpage;

import java.util.Date;

public class UpdatePageVerifyResultDto {

    private Long verifyId;

    private Integer platformType;

    private Integer pageType;

    private Long pageId;

    private String tuiaUrl;

    private String thirdUrl;

    private Integer lastStatus;

    private Date lastSendGmt;

    private Date lastCallbackGmt;

    private String refuseReason;

    private String encryptValue;

    public Integer getPlatformType() {
        return platformType;
    }

    public void setPlatformType(Integer platformType) {
        this.platformType = platformType;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public void setLastStatus(Integer lastStatus) {
        this.lastStatus = lastStatus;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public String getTuiaUrl() {
        return tuiaUrl;
    }

    public void setTuiaUrl(String tuiaUrl) {
        this.tuiaUrl = tuiaUrl;
    }

    public String getThirdUrl() {
        return thirdUrl;
    }

    public void setThirdUrl(String thirdUrl) {
        this.thirdUrl = thirdUrl;
    }

    public Integer getLastStatus() {
        return lastStatus;
    }


    public Date getLastSendGmt() {
        return lastSendGmt;
    }

    public void setLastSendGmt(Date lastSendGmt) {
        this.lastSendGmt = lastSendGmt;
    }

    public Long getVerifyId() {
        return verifyId;
    }

    public void setVerifyId(Long verifyId) {
        this.verifyId = verifyId;
    }

    public Date getLastCallbackGmt() {
        return lastCallbackGmt;
    }

    public void setLastCallbackGmt(Date lastCallbackGmt) {
        this.lastCallbackGmt = lastCallbackGmt;
    }

    public String getRefuseReason() {
        return refuseReason;
    }

    public void setRefuseReason(String refuseReason) {
        this.refuseReason = refuseReason;
    }

    public String getEncryptValue() {
        return encryptValue;
    }

    public void setEncryptValue(String encryptValue) {
        this.encryptValue = encryptValue;
    }

    @Override
    public String toString() {
        return "UpdatePageVerifyResultDto{" +
                "verifyId=" + verifyId +
                ", platformType=" + platformType +
                ", pageType=" + pageType +
                ", pageId=" + pageId +
                ", tuiaUrl='" + tuiaUrl + '\'' +
                ", thirdUrl='" + thirdUrl + '\'' +
                ", lastStatus=" + lastStatus +
                ", lastSendGmt=" + lastSendGmt +
                ", lastCallbackGmt=" + lastCallbackGmt +
                ", refuseReason='" + refuseReason + '\'' +
                ", encryptValue='" + encryptValue + '\'' +
                '}';
    }
}

==> activity-center-api-0.14.89-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/staticpage/UpdatePageVerifyResultDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.staticpage;

import java.io.Serializable;
import java.util.Date;

public class UpdatePageVerifyResultDto implements Serializable {

    private static final long serialVersionUID = -9028263127543196714L;

    private Long verifyId;

    private Integer platformType;

    private Integer pageType;

    private Long pageId;

    private String tuiaUrl;

    private String thirdUrl;

    /**
     * 平台流水号
     * e.g. 爱奇艺审核ID(fileId)
     */
    private String thirdSerialNo;

    private Integer lastStatus;

    private Date lastSendGmt;

    private Date lastCallbackGmt;

    private String refuseReason;

    private String encryptValue;

    public Integer getPlatformType() {
        return platformType;
    }

    public void setPlatformType(Integer platformType) {
        this.platformType = platformType;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public void setLastStatus(Integer lastStatus) {
        this.lastStatus = lastStatus;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public String getTuiaUrl() {
        return tuiaUrl;
    }

    public void setTuiaUrl(String tuiaUrl) {
        this.tuiaUrl = tuiaUrl;
    }

    public String getThirdUrl() {
        return thirdUrl;
    }

    public void setThirdUrl(String thirdUrl) {
        this.thirdUrl = thirdUrl;
    }

    public String getThirdSerialNo() {
        return thirdSerialNo;
    }

    public void setThirdSerialNo(String thirdSerialNo) {
        this.thirdSerialNo = thirdSerialNo;
    }

    public Integer getLastStatus() {
        return lastStatus;
    }


    public Date getLastSendGmt() {
        return lastSendGmt;
    }

    public void setLastSendGmt(Date lastSendGmt) {
        this.lastSendGmt = lastSendGmt;
    }

    public Long getVerifyId() {
        return verifyId;
    }

    public void setVerifyId(Long verifyId) {
        this.verifyId = verifyId;
    }

    public Date getLastCallbackGmt() {
        return lastCallbackGmt;
    }

    public void setLastCallbackGmt(Date lastCallbackGmt) {
        this.lastCallbackGmt = lastCallbackGmt;
    }

    public String getRefuseReason() {
        return refuseReason;
    }

    public void setRefuseReason(String refuseReason) {
        this.refuseReason = refuseReason;
    }

    public String getEncryptValue() {
        return encryptValue;
    }

    public void setEncryptValue(String encryptValue) {
        this.encryptValue = encryptValue;
    }

    @Override
    public String toString() {
        return "UpdatePageVerifyResultDto{" +
                "verifyId=" + verifyId +
                ", platformType=" + platformType +
                ", pageType=" + pageType +
                ", pageId=" + pageId +
                ", tuiaUrl='" + tuiaUrl + '\'' +
                ", thirdUrl='" + thirdUrl + '\'' +
                ", thirdSerialNo='" + thirdSerialNo + '\'' +
                ", lastStatus=" + lastStatus +
                ", lastSendGmt=" + lastSendGmt +
                ", lastCallbackGmt=" + lastCallbackGmt +
                ", refuseReason='" + refuseReason + '\'' +
                ", encryptValue='" + encryptValue + '\'' +
                '}';
    }
}
